@@ -40,12 +40,13 @@
  * ver009
    class support: ok for basic types, but methods still TDB
    (code is VERY messed up & needs to be cleaned)
- * ver010
-   Added support for embedded Lua. Try swig -lua -help for more information
+ 
+ 
 */
 
+char cvsroot_lua_cxx[] = "$Id: lua.cxx 12524 2011-03-09 21:42:38Z wsfulton $";
+
 #include "swigmod.h"
-#include "cparse.h"
 
 /**** Diagnostics:
   With the #define REPORT(), you can change the amount of diagnostics given
@@ -61,7 +62,7 @@
 void display_mapping(DOH *d) {
   if (d == 0 || !DohIsMapping(d))
     return;
-  for (Iterator it = First(d); it.item; it = Next(it)) {
+  for (DohIterator it = DohFirst(d); it.item; it = DohNext(it)) {
     if (DohIsString(it.item))
       Printf(stdout, "  %s = %s\n", it.key, it.item);
     else if (DohIsMapping(it.item))
@@ -82,15 +83,10 @@ void display_mapping(DOH *d) {
 NEW LANGUAGE NOTE:END ************************************************/
 static const char *usage = (char *) "\
 Lua Options (available with -lua)\n\
-     -elua           - Generates LTR compatible wrappers for smaller devices running elua\n\
-     -eluac          - LTR compatible wrappers in \"crass compress\" mode for elua\n\
-     -nomoduleglobal - Do not register the module name as a global variable \n\
-                       but return the module table from calls to require.\n\
+     [no additional options]\n\
 \n";
 
-static int nomoduleglobal = 0;
-static int elua_ltr = 0;
-static int eluac_ltr = 0;
+
 
 /* NEW LANGUAGE NOTE:***********************************************
  To add a new language, you need to derive your class from
@@ -107,18 +103,13 @@ private:
   File *f_wrappers;
   File *f_init;
   File *f_initbeforefunc;
+  String *PrefixPlusUnderscore;
   String *s_cmd_tab;		// table of command names
   String *s_var_tab;		// table of global variables
   String *s_const_tab;		// table of global constants
   String *s_methods_tab;	// table of class methods
-  String *s_attr_tab;		// table of class attributes
-  String *s_cls_attr_tab;	// table of class static attributes
-  String *s_cls_methods_tab;	// table of class static methods
-  String *s_cls_const_tab;	// tables of class constants(including enums)
+  String *s_attr_tab;		// table of class atributes
   String *s_luacode;		// luacode to be called during init
-  String *s_dot_get;            // table of variable 'get' functions
-  String *s_dot_set;            // table of variable 'set' functions
-  String *s_vars_meta_tab;      // metatable for variables
 
   int have_constructor;
   int have_destructor;
@@ -146,31 +137,17 @@ public:
    * Initialize member data
    * --------------------------------------------------------------------- */
 
-  LUA() :
-    f_begin(0),
-    f_runtime(0),
-    f_header(0),
-    f_wrappers(0),
-    f_init(0),
-    f_initbeforefunc(0),
-    s_cmd_tab(0),
-    s_var_tab(0),
-    s_const_tab(0),
-    s_methods_tab(0),
-    s_attr_tab(0),
-    s_cls_attr_tab(0),
-    s_cls_methods_tab(0),
-    s_cls_const_tab(0),
-    s_luacode(0),
-    s_dot_get(0),
-    s_dot_set(0),
-    s_vars_meta_tab(0),
-    have_constructor(0),
-    have_destructor(0),
-    destructor_action(0),
-    class_name(0),
-    constructor_name(0),
-    current(NO_CPP) {
+  LUA() {
+    f_begin = 0;
+    f_runtime = 0;
+    f_header = 0;
+    f_wrappers = 0;
+    f_init = 0;
+    f_initbeforefunc = 0;
+    PrefixPlusUnderscore = 0;
+
+    s_cmd_tab = s_var_tab = s_const_tab = s_luacode = 0;
+    current=NO_CPP;
   }
 
   /* NEW LANGUAGE NOTE:***********************************************
@@ -195,15 +172,6 @@ public:
       if (argv[i]) {
         if (strcmp(argv[i], "-help") == 0) {	// usage flags
           fputs(usage, stdout);
-        } else if (strcmp(argv[i], "-nomoduleglobal") == 0) {
-          nomoduleglobal = 1;
-          Swig_mark_arg(i);
-        } else if(strcmp(argv[i], "-elua") == 0) {
-          elua_ltr = 1;
-          Swig_mark_arg(i);
-        } else if(strcmp(argv[i], "-eluac") == 0) {
-          eluac_ltr = 1;
-          Swig_mark_arg(i);
         }
       }
     }
@@ -283,10 +251,6 @@ public:
     s_var_tab = NewString("");
     //    s_methods_tab    = NewString("");
     s_const_tab = NewString("");
-
-    s_dot_get = NewString("");
-    s_dot_set = NewString("");
-    s_vars_meta_tab = NewString("");
     
     s_luacode = NewString("");
     Swig_register_filebyname("luacode", s_luacode);
@@ -299,14 +263,6 @@ public:
     Printf(f_runtime, "\n");
     Printf(f_runtime, "#define SWIGLUA\n");
 
-    emitLuaFlavor(f_runtime);
-
-    if (nomoduleglobal) {
-      Printf(f_runtime, "#define SWIG_LUA_NO_MODULE_GLOBAL\n");
-    } else {
-      Printf(f_runtime, "#define SWIG_LUA_MODULE_GLOBAL\n");
-    }
-
     //    if (NoInclude) {
     //      Printf(f_runtime, "#define SWIG_NOINCLUDE\n");
     //    }
@@ -321,31 +277,12 @@ public:
     Printf(f_header, "#define SWIG_name      \"%s\"\n", module);
     Printf(f_header, "#define SWIG_init      luaopen_%s\n", module);
     Printf(f_header, "#define SWIG_init_user luaopen_%s_user\n\n", module);
-    Printf(f_header, "#define SWIG_LUACODE   luaopen_%s_luacode\n", module);
+    Printf(f_header, "#define SWIG_LUACODE   luaopen_%s_luacode\n\n", module);
 
-    if (elua_ltr || eluac_ltr)
-      Printf(f_header, "#define swig_commands  %s_map\n\n", module);
-
-    if (elua_ltr || eluac_ltr) {
-      Printf(s_cmd_tab, "\n#define MIN_OPT_LEVEL 2\n#include \"lrodefs.h\"\n");
-      Printf(s_cmd_tab, "#include \"lrotable.h\"\n");
-      Printf(s_cmd_tab, "\nconst LUA_REG_TYPE swig_constants[];\n");
-      if (elua_ltr)
-        Printf(s_cmd_tab, "const LUA_REG_TYPE mt[];\n");
-
-      Printf(s_cmd_tab, "\nconst LUA_REG_TYPE swig_commands[] = {\n");
-      Printf(s_const_tab, "\nconst LUA_REG_TYPE swig_constants[] = {\n");
-      Printf(f_wrappers, "#ifdef __cplusplus\nextern \"C\" {\n#endif\n");
-      if (elua_ltr) {
-        Printf(s_dot_get, "\nconst LUA_REG_TYPE dot_get[] = {\n");
-        Printf(s_dot_set, "\nconst LUA_REG_TYPE dot_set[] = {\n");
-      }
-    } else {
-      Printf(s_cmd_tab, "\nstatic const struct luaL_Reg swig_commands[] = {\n");
-      Printf(s_var_tab, "\nstatic swig_lua_var_info swig_variables[] = {\n");
-      Printf(s_const_tab, "\nstatic swig_lua_const_info swig_constants[] = {\n");
-      Printf(f_wrappers, "#ifdef __cplusplus\nextern \"C\" {\n#endif\n");
-    }
+    Printf(s_cmd_tab, "\nstatic const struct luaL_reg swig_commands[] = {\n");
+    Printf(s_var_tab, "\nstatic swig_lua_var_info swig_variables[] = {\n");
+    Printf(s_const_tab, "\nstatic swig_lua_const_info swig_constants[] = {\n");
+    Printf(f_wrappers, "#ifdef __cplusplus\nextern \"C\" {\n#endif\n");
 
     /* %init code inclusion, effectively in the SWIG_init function */
     Printf(f_init, "void SWIG_init_user(lua_State* L)\n{\n");
@@ -356,39 +293,11 @@ public:
     Printf(f_wrappers, "#ifdef __cplusplus\n}\n#endif\n");
 
     // Done.  Close up the module & write to the wrappers
-    if (elua_ltr || eluac_ltr) {
-      Printv(s_cmd_tab, tab4, "{LSTRKEY(\"const\"), LROVAL(swig_constants)},\n", NIL);
-      if (elua_ltr)
-        Printv(s_cmd_tab, tab4, "{LSTRKEY(\"__metatable\"), LROVAL(mt)},\n", NIL);
-      Printv(s_cmd_tab, tab4, "{LNILKEY, LNILVAL}\n", "};\n", NIL);
-      Printv(s_const_tab, tab4, "{LNILKEY, LNILVAL}\n", "};\n", NIL);
-    } else {
-      Printv(s_cmd_tab, tab4, "{0,0}\n", "};\n", NIL);
-      Printv(s_var_tab, tab4, "{0,0,0}\n", "};\n", NIL);
-      Printv(s_const_tab, tab4, "{0,0,0,0,0,0}\n", "};\n", NIL);
-    }
-
-    if (elua_ltr) {
-      /* Generate the metatable */
-      Printf(s_vars_meta_tab, "\nconst LUA_REG_TYPE mt[] = {\n");
-      Printv(s_vars_meta_tab, tab4, "{LSTRKEY(\"__index\"), LFUNCVAL(SWIG_Lua_module_get)},\n", NIL);
-      Printv(s_vars_meta_tab, tab4, "{LSTRKEY(\"__newindex\"), LFUNCVAL(SWIG_Lua_module_set)},\n", NIL);
-      Printv(s_vars_meta_tab, tab4, "{LSTRKEY(\".get\"), LROVAL(dot_get)},\n", NIL);
-      Printv(s_vars_meta_tab, tab4, "{LSTRKEY(\".set\"), LROVAL(dot_set)},\n", NIL);
-      Printv(s_vars_meta_tab, tab4, "{LNILKEY, LNILVAL}\n};\n", NIL);
-
-      Printv(s_dot_get, tab4, "{LNILKEY, LNILVAL}\n};\n", NIL);
-      Printv(s_dot_set, tab4, "{LNILKEY, LNILVAL}\n};\n", NIL);
-    }
-
-    if (elua_ltr || eluac_ltr) {
-      /* Final close up of wrappers */
-      Printv(f_wrappers, s_cmd_tab, s_dot_get, s_dot_set, s_vars_meta_tab, s_var_tab, s_const_tab, NIL);
-      SwigType_emit_type_table(f_runtime, f_wrappers);
-    } else {
-      Printv(f_wrappers, s_cmd_tab, s_var_tab, s_const_tab, NIL);
-      SwigType_emit_type_table(f_runtime, f_wrappers);
-    }
+    Printv(s_cmd_tab, tab4, "{0,0}\n", "};\n", NIL);
+    Printv(s_var_tab, tab4, "{0,0,0}\n", "};\n", NIL);
+    Printv(s_const_tab, tab4, "{0,0,0,0,0,0}\n", "};\n", NIL);
+    Printv(f_wrappers, s_cmd_tab, s_var_tab, s_const_tab, NIL);
+    SwigType_emit_type_table(f_runtime, f_wrappers);
 
     /* NEW LANGUAGE NOTE:***********************************************
      this basically combines several of the strings together
@@ -411,11 +320,9 @@ public:
     Delete(f_wrappers);
     Delete(f_init);
     Delete(f_initbeforefunc);
+    Close(f_begin);
     Delete(f_runtime);
     Delete(f_begin);
-    Delete(s_dot_get);
-    Delete(s_dot_set);
-    Delete(s_vars_meta_tab);
 
     /* Done */
     return SWIG_OK;
@@ -539,8 +446,10 @@ public:
     String *argument_check = NewString("");
     String *argument_parse = NewString("");
     String *checkfn = NULL;
+    //    String *numoutputs=NULL;
     char source[64];
-    Printf(argument_check, "SWIG_check_num_args(\"%s\",%d,%d)\n",Swig_name_str(n),num_required+args_to_ignore,num_arguments+args_to_ignore);
+    //Printf(argument_check, "SWIG_check_num_args(\"%s\",%d,%d)\n",name,num_required,num_arguments);
+    Printf(argument_check, "SWIG_check_num_args(\"%s\",%d,%d)\n",name,num_required+args_to_ignore,num_arguments+args_to_ignore);
 
     for (i = 0, p = l; i < num_arguments; i++) {
 
@@ -576,7 +485,7 @@ public:
           } else {
             Printf(argument_check, "if(lua_gettop(L)>=%s && !%s(L,%s))", source, checkfn, source);
           }
-          Printf(argument_check, " SWIG_fail_arg(\"%s\",%s,\"%s\");\n", Swig_name_str(n), source, SwigType_str(pt, 0));
+          Printf(argument_check, " SWIG_fail_arg(\"%s\",%s,\"%s\");\n", name, source, SwigType_str(pt, 0));
         }
         /* NEW LANGUAGE NOTE:***********************************************
            lua states the number of arguments passed to a function using the fn
@@ -646,7 +555,7 @@ public:
         //        }
         //        else returnval++;
         Replaceall(tm, "$source", Getattr(p, "lname"));
-        Replaceall(tm, "$target", Swig_cresult_name());
+        Replaceall(tm, "$target", "result");
         Replaceall(tm, "$arg", Getattr(p, "emit:input"));
         Replaceall(tm, "$input", Getattr(p, "emit:input"));
         Printv(outarg, tm, "\n", NIL);
@@ -667,7 +576,7 @@ public:
     this is because there is a typemap for void
     NEW LANGUAGE NOTE:END ************************************************/
     // Return value if necessary
-    if ((tm = Swig_typemap_lookup_out("out", n, Swig_cresult_name(), f, actioncode))) {
+    if ((tm = Swig_typemap_lookup_out("out", n, "result", f, actioncode))) {
       // managing the number of returning variables
       //      if (numoutputs=Getattr(tm,"numoutputs")){
       //              int i=GetInt(tm,"numoutputs");
@@ -675,7 +584,7 @@ public:
       //              returnval+=GetInt(tm,"numoutputs");
       //      }
       //        else returnval++;
-      Replaceall(tm, "$source", Swig_cresult_name());
+      Replaceall(tm, "$source", "result");
       if (GetFlag(n, "feature:new")) {
         Replaceall(tm, "$owner", "1");
       } else {
@@ -696,15 +605,15 @@ public:
 
     /* Look to see if there is any newfree cleanup code */
     if (GetFlag(n, "feature:new")) {
-      if ((tm = Swig_typemap_lookup("newfree", n, Swig_cresult_name(), 0))) {
-        Replaceall(tm, "$source", Swig_cresult_name());
+      if ((tm = Swig_typemap_lookup("newfree", n, "result", 0))) {
+        Replaceall(tm, "$source", "result");
         Printf(f->code, "%s\n", tm);
       }
     }
 
     /* See if there is any return cleanup code */
-    if ((tm = Swig_typemap_lookup("ret", n, Swig_cresult_name(), 0))) {
-      Replaceall(tm, "$source", Swig_cresult_name());
+    if ((tm = Swig_typemap_lookup("ret", n, "result", 0))) {
+      Replaceall(tm, "$source", "result");
       Printf(f->code, "%s\n", tm);
     }
 
@@ -723,7 +632,7 @@ public:
 
     /* Substitute the function name */
     Replaceall(f->code, "$symname", iname);
-    Replaceall(f->code, "$result", Swig_cresult_name());
+    Replaceall(f->code, "$result", "result");
 
     /* Dump the function out */
     /* in Lua we will not emit the destructor as a wrappered function,
@@ -743,19 +652,10 @@ public:
     NEW LANGUAGE NOTE:END ************************************************/
     /* Now register the function with the interpreter. */
     if (!Getattr(n, "sym:overloaded")) {
-      //REPORT("dispatchFunction", n);
       //      add_method(n, iname, wname, description);
-      if (current==NO_CPP || current==STATIC_FUNC) { // emit normal fns & static fns
-        String *wrapname = Swig_name_wrapper(iname);
-        if(elua_ltr || eluac_ltr)
-          Printv(s_cmd_tab, tab4, "{LSTRKEY(\"", iname, "\")", ", LFUNCVAL(", Swig_name_wrapper(iname), ")", "},\n", NIL);
-        else
-          Printv(s_cmd_tab, tab4, "{ \"", iname, "\", ", Swig_name_wrapper(iname), "},\n", NIL);
+      if (current==NO_CPP || current==STATIC_FUNC) // emit normal fns & static fns
+        Printv(s_cmd_tab, tab4, "{ \"", iname, "\", ", Swig_name_wrapper(iname), "},\n", NIL);
       //      Printv(s_cmd_tab, tab4, "{ SWIG_prefix \"", iname, "\", (swig_wrapper_func) ", Swig_name_wrapper(iname), "},\n", NIL);
-        if (getCurrentClass()) {
-          Setattr(n,"luaclassobj:wrap:name", wrapname);
-        }
-      }
     } else {
       if (!Getattr(n, "sym:nextSibling")) {
         dispatchFunction(n);
@@ -787,7 +687,6 @@ public:
   look for %typecheck(SWIG_TYPECHECK_*) in the .swg file
   NEW LANGUAGE NOTE:END ************************************************/
   void dispatchFunction(Node *n) {
-    //REPORT("dispatchFunction", n);
     /* Last node in overloaded chain */
 
     int maxargs;
@@ -820,11 +719,9 @@ public:
       sibl = Getattr(sibl, "sym:previousSibling");	// go all the way up
     String *protoTypes = NewString("");
     do {
-      String *fulldecl = Swig_name_decl(sibl);
-      Printf(protoTypes, "\n\"    %s\\n\"", fulldecl);
-      Delete(fulldecl);
+      Printf(protoTypes, "\n\"    %s(%s)\\n\"", SwigType_str(Getattr(sibl, "name"), 0), ParmList_protostr(Getattr(sibl, "wrap:parms")));
     } while ((sibl = Getattr(sibl, "sym:nextSibling")));
-    Printf(f->code, "SWIG_Lua_pusherrstring(L,\"Wrong arguments for overloaded function '%s'\\n\"\n"
+    Printf(f->code, "lua_pushstring(L,\"Wrong arguments for overloaded function '%s'\\n\"\n"
         "\"  Possible C/C++ prototypes are:\\n\"%s);\n",symname,protoTypes);
     Delete(protoTypes);
 
@@ -835,14 +732,10 @@ public:
     if (current==NO_CPP || current==STATIC_FUNC) // emit normal fns & static fns
       Printv(s_cmd_tab, tab4, "{ \"", symname, "\",", wname, "},\n", NIL);
 
-    if (getCurrentClass())
-      Setattr(n,"luaclassobj:wrap:name", wname);
-    else
-      Delete(wname);
-
     DelWrapper(f);
     Delete(dispatch);
     Delete(tmp);
+    Delete(wname);
   }
 
 
@@ -869,7 +762,7 @@ public:
     String *getName = Swig_name_wrapper(Swig_name_get(NSPACE_TODO, iname));
     String *setName = 0;
     // checking whether it can be set to or not appears to be a very error prone issue
-    // I referred to the Language::variableWrapper() to find this out
+    // I refered to the Language::variableWrapper() to find this out
     bool assignable=is_assignable(n) ? true : false;
     SwigType *type = Getattr(n, "type");
     String *tm = Swig_typemap_lookup("globalin", n, iname, 0);
@@ -884,24 +777,10 @@ public:
       setName = NewString("SWIG_Lua_set_immutable"); // error message
       //setName = NewString("0");
     }
-
     // register the variable
-    if (elua_ltr) {
-      Printf(s_dot_get, "%s{LSTRKEY(\"%s\"), LFUNCVAL(%s)},\n", tab4, iname, getName);
-      Printf(s_dot_set, "%s{LSTRKEY(\"%s\"), LFUNCVAL(%s)},\n", tab4, iname, setName);
-    } else if (eluac_ltr) {
-      Printv(s_cmd_tab, tab4, "{LSTRKEY(\"", iname, "_get", "\")", ", LFUNCVAL(", getName, ")", "},\n", NIL);
-      Printv(s_cmd_tab, tab4, "{LSTRKEY(\"", iname, "_set", "\")", ", LFUNCVAL(", setName, ")", "},\n", NIL);
-    } else {
-      Printf(s_var_tab, "%s{ \"%s\", %s, %s },\n", tab4, iname, getName, setName);
-    }
-    if (getCurrentClass()) {
-      Setattr(n, "luaclassobj:wrap:get", getName);
-      Setattr(n, "luaclassobj:wrap:set", setName);
-    } else {
-      Delete(getName);
-      Delete(setName);
-    }
+    Printf(s_var_tab, "%s{ \"%s\", %s, %s },\n", tab4, iname, getName, setName);
+    Delete(getName);
+    Delete(setName);
     return result;
   }
 
@@ -909,7 +788,7 @@ public:
    * constantWrapper()
    * ------------------------------------------------------------ */
   virtual int constantWrapper(Node *n) {
-    REPORT("constantWrapper", n);
+    //    REPORT("constantWrapper", n);
     String *name = Getattr(n, "name");
     String *iname = Getattr(n, "sym:name");
     String *nsname = Copy(iname);
@@ -933,7 +812,7 @@ public:
       Replaceall(tm, "$target", name);
       Replaceall(tm, "$value", value);
       Replaceall(tm, "$nsname", nsname);
-      Printf(s_const_tab, "    %s,\n", tm);
+      Printf(s_const_tab, "%s,\n", tm);
     } else if ((tm = Swig_typemap_lookup("constcode", n, name, 0))) {
       Replaceall(tm, "$source", value);
       Replaceall(tm, "$target", name);
@@ -945,20 +824,6 @@ public:
       Swig_warning(WARN_TYPEMAP_CONST_UNDEF, input_file, line_number, "Unsupported constant value.\n");
       return SWIG_NOWRAP;
     }
-    if (cparse_cplusplus && getCurrentClass()) {
-      // Additionally add to class constants
-      Swig_require("luaclassobj_constantWrapper", n, "*sym:name", "luaclassobj:symname", NIL);
-      Setattr(n, "sym:name", Getattr(n, "luaclassobj:symname"));
-      String *cls_nsname = Getattr(n, "sym:name");
-      if ((tm = Swig_typemap_lookup("consttab", n, name, 0))) {
-        Replaceall(tm, "$source", value);
-        Replaceall(tm, "$target", name);
-        Replaceall(tm, "$value", value);
-        Replaceall(tm, "$nsname", cls_nsname);
-        Printf(s_cls_const_tab, "    %s,\n", tm);
-      }
-      Swig_restore(n);
-    }
     Delete(nsname);
     return SWIG_OK;
   }
@@ -1025,7 +890,7 @@ public:
     real_classname = Getattr(n, "name");
     mangled_classname = Swig_name_mangle(real_classname);
 
-    // not sure exactly how this works,
+    // not sure exactly how this workswhat this works,
     // but tcl has a static hashtable of all classes emitted and then only emits code for them once.
     // this fixes issues in test suites: template_default2 & template_specialization
 
@@ -1045,19 +910,6 @@ public:
     Printf(s_methods_tab, "static swig_lua_method swig_");
     Printv(s_methods_tab, mangled_classname, "_methods[] = {\n", NIL);
 
-    s_cls_methods_tab = NewString("");
-    Printf(s_cls_methods_tab, "static swig_lua_method swig_");
-    Printv(s_cls_methods_tab, mangled_classname, "_cls_methods[] = {\n", NIL);
-
-    s_cls_attr_tab = NewString("");
-    Printf(s_cls_attr_tab, "static swig_lua_attribute swig_");
-    Printv(s_cls_attr_tab, mangled_classname, "_cls_attributes[] = {\n", NIL);
-
-    s_cls_const_tab = NewString("");
-    Printf(s_cls_const_tab, "static swig_lua_const_info swig_");
-    Printv(s_cls_const_tab, mangled_classname, "_cls_constants[] = {\n", NIL);
-
-
     // Generate normal wrappers
     Language::classHandler(n);
 
@@ -1096,24 +948,11 @@ public:
     Printf(s_attr_tab, "    {0,0,0}\n};\n");
     Printv(f_wrappers, s_attr_tab, NIL);
 
-    Printf(s_cls_attr_tab, "    {0,0,0}\n};\n");
-    Printv(f_wrappers, s_cls_attr_tab, NIL);
-
-    Printf(s_cls_methods_tab, "    {0,0}\n};\n");
-    Printv(f_wrappers, s_cls_methods_tab, NIL);
-
-    Printf(s_cls_const_tab, "    {0,0,0,0,0,0}\n};\n");
-    Printv(f_wrappers, s_cls_const_tab, NIL);
-
-
     Delete(s_methods_tab);
     Delete(s_attr_tab);
-    Delete(s_cls_methods_tab);
-    Delete(s_cls_attr_tab);
-    Delete(s_cls_const_tab);
 
     // Handle inheritance
-    // note: with the idea of class hierarchies spread over multiple modules
+    // note: with the idea of class hireachied spread over multiple modules
     // cf test-suite: imports.i
     // it is not possible to just add the pointers to the base classes to the code
     // (as sometimes these classes are not present)
@@ -1157,17 +996,7 @@ public:
     Printv(f_wrappers, "static swig_lua_class _wrap_class_", mangled_classname, " = { \"", class_name, "\", &SWIGTYPE", SwigType_manglestr(t), ",", NIL);
 
     if (have_constructor) {
-      if (elua_ltr) {
-        Printf(s_cmd_tab, "    {LSTRKEY(\"%s\"), LFUNCVAL(%s)},\n", class_name, \
-        Swig_name_wrapper(Swig_name_construct(NSPACE_TODO, constructor_name)));
-        Printf(f_wrappers, "%s", Swig_name_wrapper(Swig_name_construct(NSPACE_TODO, constructor_name)));
-      } else if (eluac_ltr) {
-        Printv(s_cmd_tab, tab4, "{LSTRKEY(\"", "new_", class_name, "\")", ", LFUNCVAL(", \
-        Swig_name_wrapper(Swig_name_construct(NSPACE_TODO, constructor_name)), ")", "},\n", NIL);
-        Printf(f_wrappers, "%s", Swig_name_wrapper(Swig_name_construct(NSPACE_TODO, constructor_name)));
-      } else {
-        Printf(f_wrappers, "%s", Swig_name_wrapper(Swig_name_construct(NSPACE_TODO, constructor_name)));
-      }
+      Printf(f_wrappers, "%s", Swig_name_wrapper(Swig_name_construct(NSPACE_TODO, constructor_name)));
       Delete(constructor_name);
       constructor_name = 0;
     } else {
@@ -1175,19 +1004,11 @@ public:
     }
 
     if (have_destructor) {
-      if (eluac_ltr) {
-        Printv(s_cmd_tab, tab4, "{LSTRKEY(\"", "free_", class_name, "\")", ", LFUNCVAL(", "swig_delete_", class_name, ")", "},\n", NIL);
-        Printv(f_wrappers, ", swig_delete_", class_name, NIL);
-      } else {
-         Printv(f_wrappers, ", swig_delete_", class_name, NIL);
-      }
+      Printv(f_wrappers, ", swig_delete_", class_name, NIL);
     } else {
       Printf(f_wrappers, ",0");
     }
-    Printf(f_wrappers, ", swig_%s_methods, swig_%s_attributes, { \"%s\", swig_%s_cls_methods, swig_%s_cls_attributes, swig_%s_cls_constants }, swig_%s_bases, swig_%s_base_names };\n\n",
-        mangled_classname, mangled_classname,
-        class_name, mangled_classname, mangled_classname, mangled_classname,
-        mangled_classname, mangled_classname);
+    Printf(f_wrappers, ", swig_%s_methods, swig_%s_attributes, swig_%s_bases, swig_%s_base_names };\n\n", mangled_classname, mangled_classname, mangled_classname, mangled_classname);
 
     //    Printv(f_wrappers, ", swig_", mangled_classname, "_methods, swig_", mangled_classname, "_attributes, swig_", mangled_classname, "_bases };\n\n", NIL);
     //    Printv(s_cmd_tab, tab4, "{ SWIG_prefix \"", class_name, "\", (swig_wrapper_func) SWIG_ObjectConstructor, &_wrap_class_", mangled_classname, "},\n", NIL);
@@ -1249,12 +1070,6 @@ public:
       sname = NewString("SWIG_Lua_set_immutable"); // error message
     }
     Printf(s_attr_tab,"%s{ \"%s\", %s, %s},\n",tab4,symname,gname,sname);
-    if (eluac_ltr) {
-      Printv(s_cmd_tab, tab4, "{LSTRKEY(\"", class_name, "_", symname, "_get", "\")", \
-      ", LFUNCVAL(", gname, ")", "},\n", NIL);
-      Printv(s_cmd_tab, tab4, "{LSTRKEY(\"", class_name, "_", symname, "_set", "\")", \
-      ", LFUNCVAL(", sname, ")", "},\n", NIL);
-    }
     Delete(gname);
     Delete(sname);
     return SWIG_OK;
@@ -1297,30 +1112,8 @@ public:
    * ---------------------------------------------------------------------- */
 
   virtual int staticmemberfunctionHandler(Node *n) {
-    REPORT("staticmemberfunctionHandler", n);
     current = STATIC_FUNC;
-    String *symname = Getattr(n, "sym:name");
-    int result = Language::staticmemberfunctionHandler(n);
-
-    if (cparse_cplusplus && getCurrentClass()) {
-      Swig_restore(n);
-    }
-    current = NO_CPP;
-    if (result != SWIG_OK)
-      return result;
-
-    if (Getattr(n, "sym:nextSibling"))
-      return SWIG_OK;
-
-    Swig_require("luaclassobj_staticmemberfunctionHandler", n, "luaclassobj:wrap:name", NIL);
-    String *name = Getattr(n, "name");
-    String *rname, *realname;
-    realname = symname ? symname : name;
-    rname = Getattr(n, "luaclassobj:wrap:name");
-    Printv(s_cls_methods_tab, tab4, "{\"", realname, "\", ", rname, "}, \n", NIL);
-    Swig_restore(n);
-
-    return SWIG_OK;
+    return Language::staticmemberfunctionHandler(n);
   }
 
   /* ------------------------------------------------------------
@@ -1330,17 +1123,8 @@ public:
    * ------------------------------------------------------------ */
 
   virtual int memberconstantHandler(Node *n) {
-    REPORT("memberconstantHandler",n);
-    String *symname = Getattr(n, "sym:name");
-    if (cparse_cplusplus && getCurrentClass()) {
-      Swig_save("luaclassobj_memberconstantHandler", n, "luaclassobj:symname", NIL);
-      Setattr(n, "luaclassobj:symname", symname);
-    }
-    int result = Language::memberconstantHandler(n);
-    if (cparse_cplusplus && getCurrentClass())
-      Swig_restore(n);
-
-    return result;
+    //    REPORT("memberconstantHandler",n);
+    return Language::memberconstantHandler(n);
   }
 
   /* ---------------------------------------------------------------------
@@ -1348,22 +1132,9 @@ public:
    * --------------------------------------------------------------------- */
 
   virtual int staticmembervariableHandler(Node *n) {
-    REPORT("staticmembervariableHandler",n);
+    //    REPORT("staticmembervariableHandler",n);
     current = STATIC_VAR;
-    String *symname = Getattr(n, "sym:name");
-    int result = Language::staticmembervariableHandler(n);
-
-    if (result != SWIG_OK)
-      return result;
-
-
-    if (Getattr(n, "wrappedasconstant"))
-      return SWIG_OK;
-
-    Swig_require("luaclassobj_staticmembervariableHandler", n, "luaclassobj:wrap:get", "luaclassobj:wrap:set", NIL);
-    Printf(s_cls_attr_tab,"%s{ \"%s\", %s, %s},\n",tab4,symname,Getattr(n,"luaclassobj:wrap:get"), Getattr(n,"luaclassobj:wrap:set"));
-    Swig_restore(n);
-    return SWIG_OK;
+    return Language::staticmembervariableHandler(n);
   }
 
   /* ---------------------------------------------------------------------
@@ -1379,10 +1150,9 @@ public:
    */
   String *runtimeCode() {
     String *s = NewString("");
-    const char *filenames[] = { "luarun.swg", 0 } ; // must be 0 terminated
-
-    emitLuaFlavor(s);
-
+    const char *filenames[] = { "luarun.swg", 0
+                              }
+                              ;	// must be 0 termiated
     String *sfile;
     for (int i = 0; filenames[i] != 0; i++) {
       sfile = Swig_include_sys(filenames[i]);
@@ -1405,16 +1175,6 @@ public:
    * helpers
    * --------------------------------------------------------------------- */
 
-  void emitLuaFlavor(String *s) {
-    if (elua_ltr)
-      Printf(s, "#define SWIG_LUA_TARGET SWIG_LUA_FLAVOR_ELUA\n");
-    else if (eluac_ltr)
-      Printf(s, "#define SWIG_LUA_TARGET SWIG_LUA_FLAVOR_ELUAC\n");
-    else
-      Printf(s, "#define SWIG_LUA_TARGET SWIG_LUA_FLAVOR_LUA\n");
-  }
-  
-
   /* This is to convert the string of Lua code into a proper string, which can then be
      emitted into the C/C++ code.
      Basically is is a lot of search & replacing of odd sequences
