@@ -11,6 +11,8 @@
  * Tcl8 language module for SWIG.
  * ----------------------------------------------------------------------------- */
 
+char cvsroot_tcl8_cxx[] = "$Id: tcl8.cxx 12564 2011-03-29 19:15:19Z wsfulton $";
+
 #include "swigmod.h"
 #include "cparse.h"
 static int treduce = SWIG_cparse_template_reduce(0);
@@ -183,7 +185,7 @@ public:
     /* If shadow classing is enabled, we're going to change the module name to "_module" */
     if (itcl) {
       String *filen;
-      filen = NewStringf("%s%s.itcl", SWIG_output_directory(), module);
+      filen = NewStringf("%s%s.itcl", Swig_file_dirname(outfile), module);
 
       Insert(module, 0, "_");
 
@@ -246,6 +248,7 @@ public:
 
     if (itcl) {
       Printv(f_shadow, f_shadow_stubs, "\n", NIL);
+      Close(f_shadow);
       Delete(f_shadow);
     }
 
@@ -256,6 +259,7 @@ public:
     Delete(f_header);
     Delete(f_wrappers);
     Delete(f_init);
+    Close(f_begin);
     Delete(f_runtime);
     Delete(f_begin);
     return SWIG_OK;
@@ -456,8 +460,8 @@ public:
     /* Need to redo all of this code (eventually) */
 
     /* Return value if necessary  */
-    if ((tm = Swig_typemap_lookup_out("out", n, Swig_cresult_name(), f, actioncode))) {
-      Replaceall(tm, "$source", Swig_cresult_name());
+    if ((tm = Swig_typemap_lookup_out("out", n, "result", f, actioncode))) {
+      Replaceall(tm, "$source", "result");
 #ifdef SWIG_USE_RESULTOBJ
       Replaceall(tm, "$target", "resultobj");
       Replaceall(tm, "$result", "resultobj");
@@ -484,14 +488,14 @@ public:
 
     /* Look for any remaining cleanup */
     if (GetFlag(n, "feature:new")) {
-      if ((tm = Swig_typemap_lookup("newfree", n, Swig_cresult_name(), 0))) {
-	Replaceall(tm, "$source", Swig_cresult_name());
+      if ((tm = Swig_typemap_lookup("newfree", n, "result", 0))) {
+	Replaceall(tm, "$source", "result");
 	Printf(f->code, "%s\n", tm);
       }
     }
 
-    if ((tm = Swig_typemap_lookup("ret", n, Swig_cresult_name(), 0))) {
-      Replaceall(tm, "$source", Swig_cresult_name());
+    if ((tm = Swig_typemap_lookup("ret", n, "result", 0))) {
+      Replaceall(tm, "$source", "result");
       Printf(f->code, "%s\n", tm);
     }
 #ifdef SWIG_USE_RESULTOBJ
@@ -532,9 +536,7 @@ public:
 	  sibl = Getattr(sibl, "sym:previousSibling");	// go all the way up
 	String *protoTypes = NewString("");
 	do {
-	  String *fulldecl = Swig_name_decl(sibl);
-	  Printf(protoTypes, "\n\"    %s\\n\"", fulldecl);
-	  Delete(fulldecl);
+	  Printf(protoTypes, "\n\"    %s(%s)\\n\"", SwigType_str(Getattr(sibl, "name"), 0), ParmList_protostr(Getattr(sibl, "wrap:parms")));
 	} while ((sibl = Getattr(sibl, "sym:nextSibling")));
 	Printf(df->code, "Tcl_SetResult(interp,(char *) "
 	       "\"Wrong number or type of arguments for overloaded function '%s'.\\n\""
@@ -744,7 +746,6 @@ public:
     have_constructor = 0;
     have_destructor = 0;
     destructor_action = 0;
-    constructor_name = 0;
 
     if (itcl) {
       constructor = NewString("");
@@ -941,7 +942,7 @@ public:
 	Printv(f_shadow, "  constructor { } {\n", NIL);
 	Printv(f_shadow, "    # This constructor will fail if called directly\n", NIL);
 	Printv(f_shadow, "    if { [info class] == \"::", class_name, "\" } {\n", NIL);
-	Printv(f_shadow, "      error \"No constructor for class ", class_name, (Getattr(n, "abstracts") ? " - class is abstract" : ""), "\"\n", NIL);
+	Printv(f_shadow, "      error \"No constructor for class ", class_name, (Getattr(n, "abstract") ? " - class is abstract" : ""), "\"\n", NIL);
 	Printv(f_shadow, "    }\n", NIL);
 	Printv(f_shadow, "  }\n", NIL);
       }
@@ -1203,8 +1204,7 @@ public:
       }
     }
 
-    if (!have_constructor)
-      constructor_name = NewString(Getattr(n, "sym:name"));
+    constructor_name = NewString(Getattr(n, "sym:name"));
     have_constructor = 1;
     return SWIG_OK;
   }
