@@ -14,6 +14,8 @@
  * run-time type checker is also handled here.
  * ----------------------------------------------------------------------------- */
 
+char cvsroot_typesys_c[] = "$Id: typesys.c 12536 2011-03-14 07:22:08Z wsfulton $";
+
 #include "swig.h"
 #include "cparse.h"
 
@@ -295,7 +297,7 @@ void SwigType_inherit_scope(Typetab *scope) {
 
 void SwigType_scope_alias(String *aliasname, Typetab *ttab) {
   String *q;
-  /*  Printf(stdout,"alias: '%s' '%p'\n", aliasname, ttab); */
+  /*  Printf(stdout,"alias: '%s' '%x'\n", aliasname, ttab); */
   q = SwigType_scope_name(current_scope);
   if (Len(q)) {
     Append(q, "::");
@@ -391,37 +393,32 @@ void SwigType_print_scope(void) {
   Hash *ttab;
   Iterator i, j;
 
-  Printf(stdout, "SCOPES start  =======================================\n");
   for (i = First(scopes); i.key; i = Next(i)) {
-    Printf(stdout, "-------------------------------------------------------------\n");
     ttab = Getattr(i.item, "typetab");
 
-    Printf(stdout, "Type scope '%s' (%p)\n", i.key, i.item);
+    Printf(stdout, "Type scope '%s' (%x)\n", i.key, i.item);
     {
       List *inherit = Getattr(i.item, "inherit");
       if (inherit) {
 	Iterator j;
 	for (j = First(inherit); j.item; j = Next(j)) {
-	  Printf(stdout, "    Inherits from '%s' (%p)\n", Getattr(j.item, "qname"), j.item);
+	  Printf(stdout, "    Inherits from '%s' (%x)\n", Getattr(j.item, "qname"), j.item);
 	}
       }
     }
+    Printf(stdout, "-------------------------------------------------------------\n");
     for (j = First(ttab); j.key; j = Next(j)) {
       Printf(stdout, "%40s -> %s\n", j.key, j.item);
     }
   }
-  Printf(stdout, "SCOPES finish =======================================\n");
 }
 
 static Typetab *SwigType_find_scope(Typetab *s, const SwigType *nameprefix) {
   Typetab *ss;
-  Typetab *s_orig = s;
   String *nnameprefix = 0;
   static int check_parent = 1;
 
-  if (Getmark(s))
-    return 0;
-  Setmark(s, 1);
+  /*  Printf(stdout,"find_scope: %x(%s) '%s'\n", s, Getattr(s,"name"), nameprefix); */
 
   if (SwigType_istemplate(nameprefix)) {
     nnameprefix = SwigType_typedef_resolve_all(nameprefix);
@@ -446,7 +443,6 @@ static Typetab *SwigType_find_scope(Typetab *s, const SwigType *nameprefix) {
     if (s) {
       if (nnameprefix)
 	Delete(nnameprefix);
-      Setmark(s_orig, 0);
       return s;
     }
     if (!s) {
@@ -466,7 +462,6 @@ static Typetab *SwigType_find_scope(Typetab *s, const SwigType *nameprefix) {
 	  if (s) {
 	    if (nnameprefix)
 	      Delete(nnameprefix);
-	    Setmark(s_orig, 0);
 	    return s;
 	  }
 	}
@@ -478,7 +473,6 @@ static Typetab *SwigType_find_scope(Typetab *s, const SwigType *nameprefix) {
   }
   if (nnameprefix)
     Delete(nnameprefix);
-  Setmark(s_orig, 0);
   return 0;
 }
 
@@ -538,53 +532,6 @@ static SwigType *_typedef_resolve(Typetab *s, String *base, int look_parent) {
   return type;
 }
 
-/* ----------------------------------------------------------------------------- 
- * template_parameters_resolve()
- *
- * For use with templates only. The template parameters are resolved. If none
- * of the parameters can be resolved, zero is returned.
- * ----------------------------------------------------------------------------- */
-
-static String *template_parameters_resolve(const String *base) {
-  List *tparms;
-  String *suffix;
-  String *type;
-  int i, sz;
-  int rep = 0;
-  type = SwigType_templateprefix(base);
-  suffix = SwigType_templatesuffix(base);
-  Append(type, "<(");
-  tparms = SwigType_parmlist(base);
-  sz = Len(tparms);
-  for (i = 0; i < sz; i++) {
-    SwigType *tpr;
-    SwigType *tp = Getitem(tparms, i);
-    if (!rep) {
-      tpr = SwigType_typedef_resolve(tp);
-    } else {
-      tpr = 0;
-    }
-    if (tpr) {
-      Append(type, tpr);
-      Delete(tpr);
-      rep = 1;
-    } else {
-      Append(type, tp);
-    }
-    if ((i + 1) < sz)
-      Append(type, ",");
-  }
-  Append(type, ")>");
-  Append(type, suffix);
-  Delete(suffix);
-  Delete(tparms);
-  if (!rep) {
-    Delete(type);
-    type = 0;
-  }
-  return type;
-}
-
 static SwigType *typedef_resolve(Typetab *s, String *base) {
   return _typedef_resolve(s, base, 1);
 }
@@ -605,6 +552,12 @@ SwigType *SwigType_typedef_resolve(const SwigType *t) {
   String *nameprefix = 0;
   int newtype = 0;
 
+  /*
+     if (!noscope) {
+     noscope = NewStringEmpty();
+     }
+   */
+
   resolved_scope = 0;
 
 #ifdef SWIG_TYPEDEF_RESOLVE_CACHE
@@ -648,9 +601,6 @@ SwigType *SwigType_typedef_resolve(const SwigType *t) {
 #endif
 	if (nameprefix) {
 	  /* Name had a prefix on it.   See if we can locate the proper scope for it */
-	  String *rnameprefix = template_parameters_resolve(nameprefix);
-	  nameprefix = rnameprefix ? Copy(rnameprefix) : nameprefix;
-	  Delete(rnameprefix);
 	  s = SwigType_find_scope(s, nameprefix);
 
 	  /* Couldn't locate a scope for the type.  */
@@ -666,7 +616,7 @@ SwigType *SwigType_typedef_resolve(const SwigType *t) {
 	  Printf(stdout, "namebase = '%s'\n", namebase);
 #endif
 	  type = typedef_resolve(s, namebase);
-	  if (type && resolved_scope) {
+	  if (type) {
 	    /* we need to look for the resolved type, this will also
 	       fix the resolved_scope if 'type' and 'namebase' are
 	       declared in different scopes */
@@ -678,7 +628,7 @@ SwigType *SwigType_typedef_resolve(const SwigType *t) {
 #ifdef SWIG_DEBUG
 	  Printf(stdout, "%s type = '%s'\n", Getattr(s, "name"), type);
 #endif
-	  if (type && (!Swig_scopename_check(type)) && resolved_scope) {
+	  if ((type) && (!Swig_scopename_check(type)) && resolved_scope) {
 	    Typetab *rtab = resolved_scope;
 	    String *qname = Getattr(resolved_scope, "qname");
 	    /* If qualified *and* the typename is defined from the resolved scope, we qualify */
@@ -717,8 +667,42 @@ SwigType *SwigType_typedef_resolve(const SwigType *t) {
        template arguments one by one to see if they can be resolved. */
 
     if (!type && SwigType_istemplate(base)) {
+      List *tparms;
+      String *suffix;
+      int i, sz;
+      int rep = 0;
+      type = SwigType_templateprefix(base);
       newtype = 1;
-      type = template_parameters_resolve(base);
+      suffix = SwigType_templatesuffix(base);
+      Append(type, "<(");
+      tparms = SwigType_parmlist(base);
+      sz = Len(tparms);
+      for (i = 0; i < sz; i++) {
+	SwigType *tpr;
+	SwigType *tp = Getitem(tparms, i);
+	if (!rep) {
+	  tpr = SwigType_typedef_resolve(tp);
+	} else {
+	  tpr = 0;
+	}
+	if (tpr) {
+	  Append(type, tpr);
+	  Delete(tpr);
+	  rep = 1;
+	} else {
+	  Append(type, tp);
+	}
+	if ((i + 1) < sz)
+	  Append(type, ",");
+      }
+      Append(type, ")>");
+      Append(type, suffix);
+      Delete(suffix);
+      Delete(tparms);
+      if (!rep) {
+	Delete(type);
+	type = 0;
+      }
     }
     if (namebase)
       Delete(namebase);
@@ -792,67 +776,6 @@ SwigType *SwigType_typedef_resolve(const SwigType *t) {
     goto return_result;
   }
   Delete(base);
-
-  /* If 'type' is an array, then the right-most qualifier in 'r' should
-     be added to 'type' after the array qualifier, so that given
-       a(7).q(volatile).double myarray     // typedef volatile double[7] myarray;
-     the type
-       q(const).myarray                    // const myarray
-     becomes
-       a(7).q(const volatile).double       // const volatile double[7]
-     and NOT
-       q(const).a(7).q(volatile).double    // non-sensical type
-  */
-  if (r && Len(r) && SwigType_isarray(type)) {
-    List *r_elem;
-    String *r_qual;
-    int r_sz;
-    r_elem = SwigType_split(r);
-    r_sz = Len(r_elem);
-    r_qual = Getitem(r_elem, r_sz-1);
-    if (SwigType_isqualifier(r_qual)) {
-      String *new_r;
-      String *new_type;
-      List *type_elem;
-      String *type_qual;
-      String *r_qual_arg;
-      int i, type_sz;
-
-      type_elem = SwigType_split(type);
-      type_sz = Len(type_elem);
-
-      for (i = 0; i < type_sz; ++i) {
-        String *e = Getitem(type_elem, i);
-        if (!SwigType_isarray(e))
-          break;
-      }
-      type_qual = Copy(Getitem(type_elem, i));
-      r_qual_arg = SwigType_parm(r_qual);
-      SwigType_add_qualifier(type_qual, r_qual_arg);
-      Delete(r_qual_arg);
-      Setitem(type_elem, i, type_qual);
-
-      new_r = NewStringEmpty();
-      for (i = 0; i < r_sz-1; ++i) {
-        Append(new_r, Getitem(r_elem, i));
-      }
-      new_type = NewStringEmpty();
-      for (i = 0; i < type_sz; ++i) {
-        Append(new_type, Getitem(type_elem, i));
-      }
-#ifdef SWIG_DEBUG
-      Printf(stdout, "r+type='%s%s' new_r+new_type='%s%s'\n", r, type, new_r, new_type);
-#endif
-
-      Delete(r);
-      r = new_r;
-      newtype = 1;
-      type = new_type;
-      Delete(type_elem);
-    }
-    Delete(r_elem);
-  }
-
   Append(r, type);
   if (newtype) {
     Delete(type);
@@ -957,7 +880,7 @@ SwigType *SwigType_typedef_qualified(const SwigType *t) {
 	  e = ty;
 	}
 	resolved_scope = 0;
-	if (typedef_resolve(current_scope, e) && resolved_scope) {
+	if (typedef_resolve(current_scope, e)) {
 	  /* resolved_scope contains the scope that actually resolved the symbol */
 	  String *qname = Getattr(resolved_scope, "qname");
 	  if (qname) {
@@ -1014,10 +937,6 @@ SwigType *SwigType_typedef_qualified(const SwigType *t) {
 	Parm *p;
 	List *parms;
 	ty = Swig_symbol_template_deftype(e, current_symtab);
-	/*
-	String *dt = Swig_symbol_template_deftype(e, current_symtab);
-	ty = Swig_symbol_type_qualify(dt, 0);
-	*/
 	e = ty;
 	parms = SwigType_parmlist(e);
 	tprefix = SwigType_templateprefix(e);
@@ -1084,9 +1003,6 @@ SwigType *SwigType_typedef_qualified(const SwigType *t) {
 	Delete(tprefix);
 	Delete(qprefix);
 	Delete(parms);
-	/*
-	Delete(dt);
-	*/
       }
       Append(result, e);
       Delete(ty);
@@ -1180,14 +1096,14 @@ int SwigType_typedef_using(const_String_or_char_ptr name) {
 
   /* See if the using name is a scope */
   /*  tt = SwigType_find_scope(current_scope,name);
-     Printf(stdout,"tt = %p, name = '%s'\n", tt, name); */
+     Printf(stdout,"tt = %x, name = '%s'\n", tt, name); */
 
   /* We set up a typedef  B --> A::B */
   Setattr(current_typetab, base, name);
 
   /* Find the scope name where the symbol is defined */
   td = SwigType_typedef_resolve(name);
-  /*  Printf(stdout,"td = '%s' %p\n", td, resolved_scope); */
+  /*  Printf(stdout,"td = '%s' %x\n", td, resolved_scope); */
   if (resolved_scope) {
     defined_name = Getattr(resolved_scope, "qname");
     if (defined_name) {
@@ -1869,13 +1785,13 @@ void SwigType_inherit_equiv(File *out) {
       Append(rlist, ck.key);
     }
     /*    Printf(stdout,"rk.key = '%s'\n", rk.key);
-       Printf(stdout,"rh = %p '%s'\n", rh,rh); */
+       Printf(stdout,"rh = %x '%s'\n", rh,rh); */
 
     bk = First(sub);
     while (bk.key) {
       prefix = SwigType_prefix(rk.key);
       Append(prefix, bk.key);
-      /*      Printf(stdout,"set %p = '%s' : '%s'\n", rh, SwigType_manglestr(prefix),prefix); */
+      /*      Printf(stdout,"set %x = '%s' : '%s'\n", rh, SwigType_manglestr(prefix),prefix); */
       mprefix = SwigType_manglestr(prefix);
       Setattr(rh, mprefix, prefix);
       mkey = SwigType_manglestr(rk.key);
